Package: heplots
Type: Package
Title: Visualizing Hypothesis Tests in Multivariate Linear Models
Version: 1.7.0
Date: 2024-05-01
Authors@R: c(
            person(given = "Michael", 
                   family = "Friendly", 
                   role=c("aut", "cre"), 
                   email="friendly@yorku.ca",
                   comment = c(ORCID = "0000-0002-3237-0941")),
            person(given = "John", 
                   family = "Fox", role="aut",
                   comment = c(ORCID = "0000-0002-1196-8012")),
            person(given = "Georges", family = "Monette", role="aut", comment = c(ORCID = "0000-0003-0076-5532")),
            person(given = "Phil", family="Chalmers", role="ctb", comment = c(ORCID="0000-0001-5332-2810")),
            person(given = "Duncan", family = "Murdoch", role="ctb"))
Maintainer: Michael Friendly <friendly@yorku.ca>
Description: Provides HE plot and other functions for visualizing hypothesis
    tests in multivariate linear models. HE plots represent sums-of-squares-and-products 
    matrices for linear hypotheses and for error using ellipses (in two
    dimensions) and ellipsoids (in three dimensions). The related 'candisc' package
    provides visualizations in a reduced-rank canonical discriminant space when
    there are more than a few response variables.
Language: en-US
Depends: R (>= 3.5.0), broom
Imports: car, MASS, graphics, grDevices, stats, magrittr, purrr, rgl,
        tibble
Suggests: candisc, carData, effects, reshape, gplots, nlme, lattice,
        reshape2, corrgram, animation, mvinfluence, knitr, rmarkdown,
        dplyr, tidyr, ggplot2, bookdown, patchwork, tinytable, glue,
        here, Sleuth2, rrcov, archdata, qqtest
LazyLoad: yes
LazyData: yes
BugReports: https://github.com/friendly/heplots/issues
License: GPL (>= 2)
URL: http://friendly.github.io/heplots/
RoxygenNote: 7.3.1
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-05-02 21:01:07 UTC; friendly
Author: Michael Friendly [aut, cre] (<https://orcid.org/0000-0002-3237-0941>),
  John Fox [aut] (<https://orcid.org/0000-0002-1196-8012>),
  Georges Monette [aut] (<https://orcid.org/0000-0003-0076-5532>),
  Phil Chalmers [ctb] (<https://orcid.org/0000-0001-5332-2810>),
  Duncan Murdoch [ctb]
Repository: CRAN
Date/Publication: 2024-05-02 21:50:02 UTC
Built: R 4.4.0; ; 2024-05-05 08:39:30 UTC; unix
