# Generated by roxygen2: do not edit by hand

S3method(Ellipsoid,data.frame)
S3method(Ellipsoid,default)
S3method(boxM,default)
S3method(boxM,formula)
S3method(boxM,lm)
S3method(coefplot,mlm)
S3method(covEllipses,boxM)
S3method(covEllipses,data.frame)
S3method(covEllipses,default)
S3method(covEllipses,formula)
S3method(covEllipses,matrix)
S3method(cqplot,default)
S3method(cqplot,mlm)
S3method(df.terms,default)
S3method(etasq,Anova.mlm)
S3method(etasq,lm)
S3method(etasq,mlm)
S3method(glance,mlm)
S3method(heplot,mlm)
S3method(heplot1d,mlm)
S3method(heplot3d,mlm)
S3method(pairs,mlm)
S3method(plot,boxM)
S3method(plot,robmlm)
S3method(print,robmlm)
S3method(print,summary.robmlm)
S3method(robmlm,default)
S3method(robmlm,formula)
S3method(stats::vcov,mlm)
S3method(summary,boxM)
S3method(summary,robmlm)
export(Ellipsoid)
export(Mahalanobis)
export(arrow3d)
export(bartlettTests)
export(bbox3d)
export(boxM)
export(coefplot)
export(colDevs)
export(colMeansList)
export(covEllipses)
export(covList)
export(cqplot)
export(cross3d)
export(df.terms)
export(ellipse.axes)
export(ellipse.box)
export(ellipse3d.axes)
export(etasq)
export(glance.mlm)
export(gsorth)
export(heplot)
export(heplot1d)
export(heplot3d)
export(interpPlot)
export(label.ellipse)
export(leveneTests)
export(logdetCI)
export(mark.H0)
export(robmlm)
export(statList)
export(termMeans)
export(trans.colors)
importFrom(MASS,cov.trob)
importFrom(MASS,psi.bisquare)
importFrom(broom,glance)
importFrom(car,Anova)
importFrom(car,dataEllipse)
importFrom(car,linearHypothesis)
importFrom(car,showLabels)
importFrom(car,wcrossprod)
importFrom(grDevices,col2rgb)
importFrom(grDevices,gray)
importFrom(grDevices,palette)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,box)
importFrom(graphics,dotchart)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(magrittr,extract)
importFrom(purrr,map)
importFrom(purrr,map_dfr)
importFrom(rgl,asEuclidean)
importFrom(stats,.getXlevels)
importFrom(stats,IQR)
importFrom(stats,SSD)
importFrom(stats,aggregate)
importFrom(stats,alias)
importFrom(stats,coefficients)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,df.residual)
importFrom(stats,estVar)
importFrom(stats,formula)
importFrom(stats,getCall)
importFrom(stats,lm.wfit)
importFrom(stats,lsfit)
importFrom(stats,mahalanobis)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.omit)
importFrom(stats,offset)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,ppoints)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,runif)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(tibble,as_tibble)
